@@ -20,13 +20,15 @@ use warnings;
 
 use base 'EBox::Menu::Node';
 use EBox::Gettext;
+use HTML::Mason::Interp;
 
-sub new 
+sub new
 {
 	my $class = shift;
 	my %opts = @_;
 	my $self = $class->SUPER::new(@_);
 	$self->{'current'} = delete $opts{'current'};
+	$self->{'id'} = 'menu';
 	bless($self, $class);
 	return $self;
 }
@@ -35,16 +37,32 @@ sub html
 {
 	my $self = shift;
 
-	my $html = "<div id='menu'>\n";
-	$html .=   "<ul id='nav'>\n";
+    my $output;
+    my $interp = HTML::Mason::Interp->new(out_method => \$output);
+    my $comp = $interp->make_component(
+            comp_file => (EBox::Config::templates . '/menu.mas'));
 
-	foreach my $item (@{$self->items}) {
-		$html .= $item->html($self->{'current'});
-	}
+    # Add separators
+    my @items;
+    my $currentSeparator = undef;
+    foreach my $item (@{$self->items}) {
+        my $itemSeparator = $item->{separator};
+        if ($itemSeparator) {
+            if ($itemSeparator ne $currentSeparator) {
+                push (@items, new EBox::Menu::Separator('text' =>
+                                                        $itemSeparator));
+                $currentSeparator = $itemSeparator;
+            }
+        }
+        push (@items, $item);
+    }
 
-	$html .= "</ul></div>\n";
+    my @params;
+    push(@params, 'items' => \@items);
+    push(@params, 'current' => $self->{'current'});
+    $interp->exec($comp, @params);
 
-	return $html;
+	return $output;
 }
 
 1;
